@@ -1,20 +1,20 @@
 use {
     crate::{
+        cli::{
+            Args,
+            CliShellInstallState,
+        },
         errors::ProgramError,
-        cli::{Args, CliShellInstallState},
-    },
-    std::{
-        env,
     },
+    std::env,
 };
 
-
 /// launch arguments related to installation
 /// (not used by the application after the first step)
 pub struct InstallLaunchArgs {
-    pub install: Option<bool>,                           // installation is required
+    pub install: Option<bool>, // installation is required
     pub set_install_state: Option<CliShellInstallState>, // the state to set
-    pub print_shell_function: Option<String>,            // shell function to print on stdout
+    pub print_shell_function: Option<String>, // shell function to print on stdout
 }
 impl InstallLaunchArgs {
     pub fn from(args: &Args) -> Result<Self, ProgramError> {
