@@ -14,16 +14,27 @@ use {
         tree::Tree,
     },
     crokey::crossterm::{
-        cursor,
-        event::{DisableMouseCapture, EnableMouseCapture},
-        terminal::{self, EnterAlternateScreen, LeaveAlternateScreen},
         QueueableCommand,
+        cursor,
+        event::{
+            DisableMouseCapture,
+            EnableMouseCapture,
+        },
+        terminal::{
+            self,
+            EnterAlternateScreen,
+            LeaveAlternateScreen,
+        },
     },
     opener,
     std::{
         env,
-        io::{self, Write},
+        io::{
+            self,
+            Write,
+        },
         path::PathBuf,
+        path::Path,
         process::Command,
     },
     which::which,
@@ -33,11 +44,8 @@ use {
 /// A launchable can only be executed on end of life of broot.
 #[derive(Debug)]
 pub enum Launchable {
-
     /// just print something on stdout on end of broot
-    Printer {
-        to_print: String,
-    },
+    Printer { to_print: String },
 
     /// print the tree on end of broot
     TreePrinter {
@@ -59,9 +67,7 @@ pub enum Launchable {
     },
 
     /// open a path
-    SystemOpen {
-        path: PathBuf,
-    },
+    SystemOpen { path: PathBuf },
 }
 
 /// If a part starts with a '$', replace it by the environment variable of the same name.
@@ -141,7 +147,13 @@ impl Launchable {
                 println!("{to_print}");
                 Ok(())
             }
-            Launchable::TreePrinter { tree, skin, ext_colors, width, height } => {
+            Launchable::TreePrinter {
+                tree,
+                skin,
+                ext_colors,
+                width,
+                height,
+            } => {
                 let dp = DisplayableTree::out_of_app(tree, skin, ext_colors, *width, *height);
                 dp.write_on(&mut std::io::stdout())
             }
@@ -175,7 +187,10 @@ impl Launchable {
                 let mut old_working_dir = None;
                 if let Some(working_dir) = working_dir {
                     old_working_dir = std::env::current_dir().ok();
-                    std::env::set_current_dir(working_dir).unwrap();
+                    if !try_set_current_dir(working_dir) {
+                        warn!("Unable to set working dir to {working_dir:?}");
+                        old_working_dir = None;
+                    }
                 }
                 let exec_res = Command::new(exe)
                     .args(args.iter())
@@ -200,7 +215,9 @@ impl Launchable {
                     }
                 }
                 if let Some(old_working_dir) = old_working_dir {
-                    std::env::set_current_dir(old_working_dir).unwrap();
+                    if !try_set_current_dir(&old_working_dir) {
+                        warn!("Unable to restore working dir to {old_working_dir:?}");
+                    }
                 }
                 exec_res?; // we trigger the error display after restoration
                 Ok(())
@@ -212,3 +229,18 @@ impl Launchable {
         }
     }
 }
+
+/// Try set the current dir to the given path, and if it fails, try to climb the path until an
+/// existing folder is found. Return true if the current dir has been changed, false otherwise.
+pub fn try_set_current_dir(mut dir: &Path) -> bool {
+    loop {
+        if std::env::set_current_dir(dir).is_ok() {
+            debug!("Working dir set to {dir:?}");
+            return true;
+        }
+        let Some(parent_dir) = dir.parent() else {
+            return false;
+        };
+        dir = parent_dir;
+    }
+}
