@@ -5,8 +5,8 @@ mod help_mad_skin;
 mod panel_skin;
 mod purpose_mad_skin;
 mod skin_entry;
-mod style_map;
 mod status_mad_skin;
+mod style_map;
 
 pub use {
     app_skin::AppSkin,
@@ -16,11 +16,17 @@ pub use {
     panel_skin::PanelSkin,
     purpose_mad_skin::*,
     skin_entry::SkinEntry,
-    style_map::{StyleMap, StyleMaps},
     status_mad_skin::StatusMadSkinSet,
+    style_map::{
+        StyleMap,
+        StyleMaps,
+    },
 };
 
-use crokey::crossterm::style::Color::{self, *};
+use crokey::crossterm::style::Color::{
+    self,
+    *,
+};
 
 pub fn gray(mut level: u8) -> Option<Color> {
     if level > 23 {
@@ -31,7 +37,11 @@ pub fn gray(mut level: u8) -> Option<Color> {
     Some(AnsiValue(0xE8 + level))
 }
 
-pub fn rgb(r: u8, g: u8, b: u8) -> Option<Color> {
+pub fn rgb(
+    r: u8,
+    g: u8,
+    b: u8,
+) -> Option<Color> {
     Some(Rgb { r, g, b })
 }
 
